@@ -69,7 +69,10 @@ QvkMainWindow_wl::QvkMainWindow_wl( QWidget *parent, Qt::WindowFlags f )
     supportedImageFormats();
 
     QFile fileCSS( ":/pictures/css/css.qss" );
-    fileCSS.open( QFile::ReadOnly | QFile::Text );
+    bool boCSS = fileCSS.open( QFile::ReadOnly | QFile::Text );
+    if ( boCSS == false ) {
+        qDebug().noquote() << global::nameOutput << "Can not open" << fileCSS.fileName();
+    }
     QTextStream streamCSS( &fileCSS );
     qApp->setStyleSheet( streamCSS.readAll() );
     fileCSS.close();
@@ -95,6 +98,9 @@ QvkMainWindow_wl::QvkMainWindow_wl( QWidget *parent, Qt::WindowFlags f )
     QvkInformation_wl *vkInformation = new QvkInformation_wl( this, ui );
     connect( this, SIGNAL( signal_newVideoFilename(QString) ), vkInformation, SLOT( slot_newVideoFilename(QString) ) );
     connect( this, SIGNAL( signal_beginRecordTime(QString) ),  vkInformation, SLOT( slot_beginRecordTime(QString) ) );
+
+    vkRegionMargins_wl = new QvkRegionMargins_wl( ui );
+
     set_RegionChoice();
     set_Connects();
     set_check_screencast_elements_available();
@@ -173,7 +179,8 @@ QvkMainWindow_wl::QvkMainWindow_wl( QWidget *parent, Qt::WindowFlags f )
         connect( vkSystray,                 SIGNAL( signal_SystemtrayIsClose() ), this,      SLOT( close() ) );
     }
 
-    vkSettings.readAll( ui, this );
+    vkSettings_wl.readAll( ui, this );
+    vkSettings_wl.readAreaScreencast( vkRegionChoise_wl );
 
     ui->widgetLanguageAndHelp->setVisible( false );
  }
@@ -200,7 +207,12 @@ void QvkMainWindow_wl::closeEvent( QCloseEvent *event )
 
     ui->pushButtonStop->click();
     vkRegionChoise_wl->close();
-    vkSettings.saveAll( ui, this );
+    vkSettings_wl.saveAll( ui, this );
+    vkSettings_wl.saveAreaScreencast( vkRegionChoise_wl->get_XRecordArea() / vkRegionChoise_wl->screen()->devicePixelRatio(),
+                                      vkRegionChoise_wl->get_YRecordArea() / vkRegionChoise_wl->screen()->devicePixelRatio(),
+                                      vkRegionChoise_wl->get_WidthRecordArea() / vkRegionChoise_wl->screen()->devicePixelRatio(),
+                                      vkRegionChoise_wl->get_HeightRecordArea() / vkRegionChoise_wl->screen()->devicePixelRatio()
+                                      );
     vkSystray->deleteLater();
 
     qDebug().noquote() << global::nameOutput << "QvkMainWindow_wl::closeEvent End close";
@@ -210,7 +222,10 @@ void QvkMainWindow_wl::closeEvent( QCloseEvent *event )
 void QvkMainWindow_wl::slot_log_refresh()
 {
     QFile file( vkLogController->get_log_filePath() );
-    file.open( QIODevice::ReadOnly );
+    bool bo = file.open( QIODevice::ReadOnly );
+    if ( bo == false ) {
+        qDebug().noquote() << global::nameOutput << "Can not open" << file.fileName();
+    }
     QTextStream in( &file );
     ui->textBrowser->clear();
     ui->textBrowser->setText( in.readAll() );
@@ -299,10 +314,6 @@ void QvkMainWindow_wl::get_system_info()
             ui->radioButtonScreencastArea->hide();
             ui->frame_area->hide();
             ui->toolButtonScreencastAreaReset->hide();
-            ui->toolButton_area_top->hide();
-            ui->toolButton_area_right->hide();
-            ui->toolButton_area_bottom->hide();
-            ui->toolButton_area_left->hide();
         }
     }
     if ( QSystemTrayIcon::isSystemTrayAvailable() == true ) {
@@ -315,10 +326,10 @@ void QvkMainWindow_wl::get_system_info()
     qDebug().noquote() << global::nameOutput << "Qt-PluginsPath:     " << QLibraryInfo::path( QLibraryInfo::PluginsPath );
     qDebug().noquote() << global::nameOutput << "Qt-TranslationsPath:" << QLibraryInfo::path( QLibraryInfo::TranslationsPath );
     qDebug().noquote() << global::nameOutput << "Qt-LibraryPath:     " << QLibraryInfo::path( QLibraryInfo::LibrariesPath );
-//    qDebug().noquote() << global::nameOutput << "Settings:" << vkSettings.getFileName();
-    qDebug().noquote() << global::nameOutput << "Log:" << vkLogController->get_log_filePath();
+    qDebug().noquote() << global::nameOutput << "SettingsPath:" << vkSettings_wl.getFileName();
+    qDebug().noquote() << global::nameOutput << "LogPath:" << vkLogController->get_log_filePath();
     qDebug().noquote() << global::nameOutput << "Default Videopath:" << QStandardPaths::writableLocation( QStandardPaths::MoviesLocation );
-//    qDebug().noquote() << global::nameOutput << "User Videopath:" << vkSettings.getVideoPath();
+//    qDebug().noquote() << global::nameOutput << "User Videopath:" << vkSettings_wl.getVideoPath();
     qDebug().noquote();
 }
 
@@ -364,7 +375,9 @@ void QvkMainWindow_wl::set_Connects()
     connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), ui->frame_video,                     SLOT( setEnabled(bool) ) );
     connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), ui->frame_audio,                     SLOT( setEnabled(bool) ) );
     connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), ui->frame_3,                         SLOT( setEnabled(bool) ) );
-    connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), this,                                SLOT( slot_portal_start() ) );
+//    connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), this,                                SLOT( slot_portal_start() ) );
+    connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), this,                                SLOT( slot_pre_portal_start() ) );
+    connect( vkRegionMargins_wl,  SIGNAL( signal_regionMargins() ), this,                       SLOT( slot_portal_start() ) );
 
     connect( ui->pushButtonStop,  SIGNAL( clicked(bool) ), this,                                SLOT( slot_stop() ) );
     connect( ui->pushButtonStop,  SIGNAL( clicked(bool) ), ui->pushButtonStop,                  SLOT( setEnabled(bool) ) );
@@ -413,10 +426,20 @@ void QvkMainWindow_wl::set_Connects()
 
     connect( ui->toolButtonScreencastAreaReset, SIGNAL( clicked(bool) ), vkRegionChoise_wl, SLOT( slot_areaReset() ) );
     connect( ui->toolButtonFramesReset,         SIGNAL( clicked(bool) ), this,              SLOT( slot_frames_Reset() ) );
-    connect( ui->toolButtonOpenh264Reset,       SIGNAL( clicked(bool) ), this, SLOT( slot_openh264Reset() ) );
+    connect( ui->toolButtonOpenh264Reset,       SIGNAL( clicked(bool) ), this,              SLOT( slot_openh264Reset() ) );
 
-    connect( ui->pushButtonSnapshot, SIGNAL( clicked(bool) ), this, SLOT( slot_snapshotHideBeforeRecording(bool) ) );
+    connect( ui->pushButtonSnapshot,           SIGNAL( clicked(bool) ), this, SLOT( slot_snapshotHideBeforeRecording(bool) ) );
     connect( ui->pushButtonSnapshotOpenFolder, SIGNAL( clicked(bool) ), this, SLOT( slot_path_to_snapshot_folder(bool) ) );
+    connect( ui->toolButtonSnapshotFormatsReset, &QPushButton::clicked, this, [=]() {
+        ui->comboBoxSnapshotImageFormats->setCurrentText( "png" ); } );
+    connect( ui->toolButtonSnapshotHideBeforeRecordingReset, &QPushButton::clicked, this, [=]() {
+        ui->checkBoxSnapshotHideBeforeRecording->setChecked( false ); } );
+    QvkSpezialSlider *spezialSlider = ui->centralwidget->findChild<QvkSpezialSlider *>( "sliderWaitBeforeSnapshot" );
+    connect( ui->toolButtonSnapshotSecondsWaitBeforeRecordingReset, &QPushButton::clicked, this, [=]() {
+        spezialSlider->setValue(4); } );
+
+
+
 
     connect( ui->pushButton_log_openfolder, SIGNAL( clicked(bool) ), this, SLOT( slot_log_folder() ) );
     connect( ui->pushButton_log_refresh,    SIGNAL( clicked(bool) ), this, SLOT( slot_log_refresh() ) );
@@ -428,12 +451,11 @@ void QvkMainWindow_wl::slot_snapshotHideBeforeRecording( bool bo ) {
     if ( ui->checkBoxSnapshotHideBeforeRecording->isChecked() == true ) {
         qDebug().noquote() << global::nameOutput << "[Snapshot]" << "Hide this window is checked";
         showMinimized();
-        QvkSpezialSlider *spezialSlider = ui->centralwidget->findChild<QvkSpezialSlider *>( "sliderWaitBeforeSnapshot" );
-        QTimer::singleShot( spezialSlider->value() * 100, Qt::PreciseTimer, this, SLOT( slot_pushButton_snapshot() ) );
     } else {
         qDebug().noquote() << global::nameOutput << "[Snapshot]" << "Hide this window is not checked";
-        slot_pushButton_snapshot();
     }
+    QvkSpezialSlider *spezialSlider = ui->centralwidget->findChild<QvkSpezialSlider *>( "sliderWaitBeforeSnapshot" );
+    QTimer::singleShot( spezialSlider->value() * 100, Qt::PreciseTimer, this, SLOT( slot_pushButton_snapshot() ) );
 }
 
 
@@ -529,10 +551,11 @@ void QvkMainWindow_wl::supportedImageFormats()
     ui->comboBoxSnapshotImageFormats->setCurrentIndex( ui->comboBoxSnapshotImageFormats->findText( "png" ) );
 }
 
-
 //------------------------------------------------
 //             pushButtonStart
 //                   |
+//            slot_pre_portal_start
+//                   |
 //            slot_portal_start
 //                   |
 //     portal_wl->slot_startScreenCast
@@ -549,6 +572,26 @@ void QvkMainWindow_wl::supportedImageFormats()
 //        |
 //
 //------------------------------------------------
+
+void QvkMainWindow_wl::slot_pre_portal_start()
+{
+    if ( ui->radioButtonScreencastArea->isChecked() ) {
+        vkRegionMargins_wl->setVisible(true);
+        vkRegionMargins_wl->slot_singleShot(true);
+    }
+
+    if ( ui->radioButtonScreencastWindow->isChecked() ) {
+        slot_portal_start();
+    }
+
+    if ( ui->radioButtonScreencastFullscreen->isChecked() ) {
+        slot_portal_start();
+    }
+
+    qDebug().noquote() << global::nameOutput << "[QvkMainWindow_wl] slot_pre_portal_start()";
+}
+
+
 void QvkMainWindow_wl::slot_portal_start()
 {
     // Value 1 = MONITOR
@@ -598,21 +641,10 @@ QString QvkMainWindow_wl::get_Area_Videocrop()
     int divBottom = 0;
     int divLeft = 0;
 
-    if ( ui->toolButton_area_top->isChecked() == true ) {
-        divTop = ( screen()->size().height() * vkRegionChoise_wl->myDevicePixelRatio() ) - vkRegionChoise_wl->get_height_from_window();
-    }
-
-    if ( ui->toolButton_area_right->isChecked() == true ) {
-        divRight = ( screen()->size().width() * vkRegionChoise_wl->myDevicePixelRatio() ) - vkRegionChoise_wl->get_width_from_window();
-    }
-
-    if ( ui->toolButton_area_bottom->isChecked() == true ) {
-        divBottom = ( screen()->size().height() * vkRegionChoise_wl->myDevicePixelRatio() ) - vkRegionChoise_wl->get_height_from_window();
-    }
-
-    if ( ui->toolButton_area_left->isChecked() == true ) {
-        divLeft = ( screen()->size().width() * vkRegionChoise_wl->myDevicePixelRatio() ) - vkRegionChoise_wl->get_width_from_window();
-    }
+    divTop    = vkRegionMargins_wl->get_top();
+    divRight  = vkRegionMargins_wl->get_right();
+    divBottom = vkRegionMargins_wl->get_bottom();
+    divLeft   = vkRegionMargins_wl->get_left();
 
     QString top    = QString::number( vkRegionChoise_wl->get_YRecordArea() + divTop );
     QString right  = QString::number( vkRegionChoise_wl->get_width_from_window() - ( vkRegionChoise_wl->get_XRecordArea() + vkRegionChoise_wl->get_WidthRecordArea() - divRight ) );
@@ -624,7 +656,7 @@ QString QvkMainWindow_wl::get_Area_Videocrop()
                        << vkRegionChoise_wl->screen()->name() + ","
                        << vkRegionChoise_wl->screen()->manufacturer() + ","
                        << vkRegionChoise_wl->screen()->model() + ","
-                       << QString::number( vkRegionChoise_wl->screen()->size().width() ) + "x" + QString::number( vkRegionChoise_wl->screen()->size().height() );
+                       << QString::number( vkRegionChoise_wl->screen()->size().width() ) + "x" + QString::number( vkRegionChoise_wl->screen()->size().height() ) + videocrop;
 
     return videocrop;
 }
@@ -827,7 +859,6 @@ void QvkMainWindow_wl::slot_start_gst( QString vk_fd, QString vk_path )
     VK_Pipeline = VK_Pipeline.replace( "mix. !", "mix." );
     VK_Pipeline = VK_Pipeline.replace( "mux. !", "mux." );
 
-    qDebug();
     qDebug().noquote() << global::nameOutput << "Free disk space at the beginning of the recording:" << ui->labelFreeSize->text() << "MB";
     qDebug();
     qDebug().noquote() << global::nameOutput << "Separated audio tracks:" << ui->checkBoxSeparatedAudioTracks->isChecked();
@@ -854,7 +885,7 @@ void QvkMainWindow_wl::slot_start_gst( QString vk_fd, QString vk_path )
     if ( ret == GST_STATE_CHANGE_NO_PREROLL ){ qDebug().noquote() << global::nameOutput << "Start was clicked" << "GST_STATE_CHANGE_NO_PREROLL" << "Returncode =" << ret; }// 3
     if ( ret == GST_STATE_CHANGE_FAILURE )
     {
-        qDebug().noquote() << global::name << "Unable to set the pipeline to the playing state.";
+        qDebug().noquote() << global::nameOutput << "Unable to set the pipeline to the playing state.";
         gst_object_unref( pipeline );
         return;
     }
@@ -915,6 +946,7 @@ void QvkMainWindow_wl::slot_stop()
     Q_UNUSED(ret);
     gst_object_unref( pipeline );
     qDebug().noquote() << global::nameOutput << "Stop record";
+    qDebug().noquote() << global::nameOutput << "Free disk space at the end of the recording:" << ui->labelFreeSize->text() << "MB";
 
     if ( ui->radioButtonScreencastArea->isChecked() ) {
        vkRegionChoise_wl->set_recordMode( false );
@@ -940,11 +972,13 @@ void QvkMainWindow_wl::slot_portal_dialog_aborted()
        ui->toolButtonScreencastAreaReset->setEnabled( true );
     }
 
-    vkSystray->startAction->setEnabled(true);
-    vkSystray->stopAction->setEnabled(false);
-    vkSystray->pauseAction->setEnabled(false);
-    vkSystray->continueAction->setEnabled(false);
-    vkSystray->slot_setSystrayIcon(true);
+    if ( QSystemTrayIcon::isSystemTrayAvailable() == true ) {
+        vkSystray->startAction->setEnabled(true);
+        vkSystray->stopAction->setEnabled(false);
+        vkSystray->pauseAction->setEnabled(false);
+        vkSystray->continueAction->setEnabled(false);
+        vkSystray->slot_setSystrayIcon(true);
+    }
 }
 
 
@@ -1150,31 +1184,6 @@ void QvkMainWindow_wl::set_RegionChoice()
 {
     vkRegionChoise_wl = new QvkRegionChoise_wl( ui );
     connect( ui->radioButtonScreencastArea, SIGNAL( toggled(bool) ), vkRegionChoise_wl, SLOT( setVisible(bool) ) );
-
-    connect( ui->toolButton_area_top, &QPushButton::clicked, this, [=]() { ui->toolButton_area_top->setIcon( QIcon( ":/pictures/screencast/accept.png" ) );
-                                                                           ui->toolButton_area_right->setIcon( QIcon( "" ) );
-                                                                           ui->toolButton_area_bottom->setIcon( QIcon( "" ) );
-                                                                           ui->toolButton_area_left->setIcon( QIcon( "" ) );
-                                                                         } );
-
-    connect( ui->toolButton_area_right, &QPushButton::clicked, this, [=]() { ui->toolButton_area_right->setIcon( QIcon( ":/pictures/screencast/accept.png" ) );
-                                                                             ui->toolButton_area_bottom->setIcon( QIcon( "" ) );
-                                                                             ui->toolButton_area_left->setIcon( QIcon( "" ) );
-                                                                             ui->toolButton_area_top->setIcon( QIcon( "" ) );
-                                                                           } );
-
-    connect( ui->toolButton_area_bottom, &QPushButton::clicked, this, [=]() { ui->toolButton_area_bottom->setIcon( QIcon( ":/pictures/screencast/accept.png" ) );
-                                                                              ui->toolButton_area_left->setIcon( QIcon( "" ) );
-                                                                              ui->toolButton_area_top->setIcon( QIcon( "" ) );
-                                                                              ui->toolButton_area_right->setIcon( QIcon( "" ) );
-                                                                            } );
-
-    connect( ui->toolButton_area_left, &QPushButton::clicked, this, [=]() { ui->toolButton_area_left->setIcon( QIcon( ":/pictures/screencast/accept.png" ) );
-                                                                            ui->toolButton_area_top->setIcon( QIcon( "" ) );
-                                                                            ui->toolButton_area_right->setIcon( QIcon( "" ) );
-                                                                            ui->toolButton_area_bottom->setIcon( QIcon( "" ) );
-                                                                          } );
-
     vkRegionChoise_wl->slot_init();
 }
 
